Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(650)

Unified Diff: Source/core/html/HTMLObjectElement.cpp

Issue 1115353002: Update renderer to layoutObject in core/html. (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/html/HTMLMeterElement.cpp ('k') | Source/core/html/HTMLOptGroupElement.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/html/HTMLObjectElement.cpp
diff --git a/Source/core/html/HTMLObjectElement.cpp b/Source/core/html/HTMLObjectElement.cpp
index 4312738a1f1fc63b3295ad551107ff32f375480c..a1e4cd2d46b37567ce7c0b32cbacc90ee653355a 100644
--- a/Source/core/html/HTMLObjectElement.cpp
+++ b/Source/core/html/HTMLObjectElement.cpp
@@ -77,7 +77,7 @@ DEFINE_TRACE(HTMLObjectElement)
LayoutPart* HTMLObjectElement::existingLayoutPart() const
{
- return layoutPart(); // This will return 0 if the renderer is not a LayoutPart.
+ return layoutPart(); // This will return 0 if the layoutObject is not a LayoutPart.
}
bool HTMLObjectElement::isPresentationAttribute(const QualifiedName& name) const
@@ -108,7 +108,7 @@ void HTMLObjectElement::parseAttribute(const QualifiedName& name, const AtomicSt
// reload stuff when a persistable widget-type is specified?
reloadPluginOnAttributeChange(name);
if (!layoutObject())
- requestPluginCreationWithoutRendererIfPossible();
+ requestPluginCreationWithoutLayoutObjectIfPossible();
} else if (name == dataAttr) {
m_url = stripLeadingAndTrailingHTMLSpaces(value);
if (layoutObject() && isImageType()) {
@@ -293,7 +293,7 @@ void HTMLObjectElement::updateWidgetInternal()
return;
}
// FIXME: Is it possible to get here without a renderer now that we don't have beforeload events?
if (!layoutObject())
return;
« no previous file with comments | « Source/core/html/HTMLMeterElement.cpp ('k') | Source/core/html/HTMLOptGroupElement.h » ('j') | no next file with comments »
@@ -293,7 +293,7 @@ void HTMLObjectElement::updateWidgetInternal()
return;
}
- // FIXME: Is it possible to get here without a renderer now that we don't have beforeload events?
+ // FIXME: Is it possible to get here without a layoutObject now that we don't have beforeload events?
if (!layoutObject())
return;

Powered by Google App Engine
This is Rietveld 408576698